aboutsummaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorJohn Newbery <john@johnnewbery.com>2017-03-09 09:44:57 -0500
committerJohn Newbery <john@johnnewbery.com>2017-03-20 10:40:31 -0400
commitc28ee91db07ce82e134d500ddeb5600363c98048 (patch)
tree650469da9d5dc6ea5e82392348f8486fc4140261
parent00902c48cdc5d6a531abfd279fd8e7779cf0a0b8 (diff)
downloadbitcoin-c28ee91db07ce82e134d500ddeb5600363c98048.tar.xz
Rename rpc-tests directory to functional
-rw-r--r--.travis.yml2
-rw-r--r--Makefile.am14
-rw-r--r--README.md2
-rw-r--r--configure.ac3
-rwxr-xr-xcontrib/devtools/copyright_header.py2
-rw-r--r--doc/developer-notes.md4
-rw-r--r--test/README.md6
-rw-r--r--test/functional/.gitignore (renamed from test/rpc-tests/.gitignore)0
-rw-r--r--test/functional/README.md (renamed from test/rpc-tests/README.md)0
-rwxr-xr-xtest/functional/abandonconflict.py (renamed from test/rpc-tests/abandonconflict.py)0
-rwxr-xr-xtest/functional/assumevalid.py (renamed from test/rpc-tests/assumevalid.py)0
-rwxr-xr-xtest/functional/bip65-cltv-p2p.py (renamed from test/rpc-tests/bip65-cltv-p2p.py)0
-rwxr-xr-xtest/functional/bip65-cltv.py (renamed from test/rpc-tests/bip65-cltv.py)0
-rwxr-xr-xtest/functional/bip68-112-113-p2p.py (renamed from test/rpc-tests/bip68-112-113-p2p.py)0
-rwxr-xr-xtest/functional/bip68-sequence.py (renamed from test/rpc-tests/bip68-sequence.py)0
-rwxr-xr-xtest/functional/bip9-softforks.py (renamed from test/rpc-tests/bip9-softforks.py)0
-rwxr-xr-xtest/functional/bipdersig-p2p.py (renamed from test/rpc-tests/bipdersig-p2p.py)0
-rwxr-xr-xtest/functional/bipdersig.py (renamed from test/rpc-tests/bipdersig.py)0
-rwxr-xr-xtest/functional/blockchain.py (renamed from test/rpc-tests/blockchain.py)0
-rwxr-xr-xtest/functional/bumpfee.py (renamed from test/rpc-tests/bumpfee.py)0
-rwxr-xr-xtest/functional/create_cache.py (renamed from test/rpc-tests/create_cache.py)2
-rwxr-xr-xtest/functional/decodescript.py (renamed from test/rpc-tests/decodescript.py)0
-rwxr-xr-xtest/functional/disablewallet.py (renamed from test/rpc-tests/disablewallet.py)0
-rwxr-xr-xtest/functional/forknotify.py (renamed from test/rpc-tests/forknotify.py)0
-rwxr-xr-xtest/functional/fundrawtransaction.py (renamed from test/rpc-tests/fundrawtransaction.py)0
-rwxr-xr-xtest/functional/getblocktemplate_longpoll.py (renamed from test/rpc-tests/getblocktemplate_longpoll.py)0
-rwxr-xr-xtest/functional/getblocktemplate_proposals.py (renamed from test/rpc-tests/getblocktemplate_proposals.py)0
-rwxr-xr-xtest/functional/getchaintips.py (renamed from test/rpc-tests/getchaintips.py)0
-rwxr-xr-xtest/functional/httpbasics.py (renamed from test/rpc-tests/httpbasics.py)0
-rwxr-xr-xtest/functional/import-rescan.py (renamed from test/rpc-tests/import-rescan.py)0
-rwxr-xr-xtest/functional/importmulti.py (renamed from test/rpc-tests/importmulti.py)0
-rwxr-xr-xtest/functional/importprunedfunds.py (renamed from test/rpc-tests/importprunedfunds.py)0
-rwxr-xr-xtest/functional/invalidateblock.py (renamed from test/rpc-tests/invalidateblock.py)0
-rwxr-xr-xtest/functional/invalidblockrequest.py (renamed from test/rpc-tests/invalidblockrequest.py)0
-rwxr-xr-xtest/functional/invalidtxrequest.py (renamed from test/rpc-tests/invalidtxrequest.py)0
-rwxr-xr-xtest/functional/keypool.py (renamed from test/rpc-tests/keypool.py)0
-rwxr-xr-xtest/functional/listsinceblock.py (renamed from test/rpc-tests/listsinceblock.py)0
-rwxr-xr-xtest/functional/listtransactions.py (renamed from test/rpc-tests/listtransactions.py)0
-rwxr-xr-xtest/functional/maxblocksinflight.py (renamed from test/rpc-tests/maxblocksinflight.py)0
-rwxr-xr-xtest/functional/maxuploadtarget.py (renamed from test/rpc-tests/maxuploadtarget.py)0
-rwxr-xr-xtest/functional/mempool_limit.py (renamed from test/rpc-tests/mempool_limit.py)0
-rwxr-xr-xtest/functional/mempool_packages.py (renamed from test/rpc-tests/mempool_packages.py)0
-rwxr-xr-xtest/functional/mempool_reorg.py (renamed from test/rpc-tests/mempool_reorg.py)0
-rwxr-xr-xtest/functional/mempool_resurrect_test.py (renamed from test/rpc-tests/mempool_resurrect_test.py)0
-rwxr-xr-xtest/functional/mempool_spendcoinbase.py (renamed from test/rpc-tests/mempool_spendcoinbase.py)0
-rwxr-xr-xtest/functional/merkle_blocks.py (renamed from test/rpc-tests/merkle_blocks.py)0
-rwxr-xr-xtest/functional/multi_rpc.py (renamed from test/rpc-tests/multi_rpc.py)0
-rwxr-xr-xtest/functional/nodehandling.py (renamed from test/rpc-tests/nodehandling.py)0
-rwxr-xr-xtest/functional/nulldummy.py (renamed from test/rpc-tests/nulldummy.py)0
-rwxr-xr-xtest/functional/p2p-acceptblock.py (renamed from test/rpc-tests/p2p-acceptblock.py)0
-rwxr-xr-xtest/functional/p2p-compactblocks.py (renamed from test/rpc-tests/p2p-compactblocks.py)0
-rwxr-xr-xtest/functional/p2p-feefilter.py (renamed from test/rpc-tests/p2p-feefilter.py)0
-rwxr-xr-xtest/functional/p2p-fullblocktest.py (renamed from test/rpc-tests/p2p-fullblocktest.py)0
-rwxr-xr-xtest/functional/p2p-leaktests.py (renamed from test/rpc-tests/p2p-leaktests.py)0
-rwxr-xr-xtest/functional/p2p-mempool.py (renamed from test/rpc-tests/p2p-mempool.py)0
-rwxr-xr-xtest/functional/p2p-segwit.py (renamed from test/rpc-tests/p2p-segwit.py)0
-rwxr-xr-xtest/functional/p2p-timeouts.py (renamed from test/rpc-tests/p2p-timeouts.py)0
-rwxr-xr-xtest/functional/p2p-versionbits-warning.py (renamed from test/rpc-tests/p2p-versionbits-warning.py)0
-rwxr-xr-xtest/functional/preciousblock.py (renamed from test/rpc-tests/preciousblock.py)0
-rwxr-xr-xtest/functional/prioritise_transaction.py (renamed from test/rpc-tests/prioritise_transaction.py)0
-rwxr-xr-xtest/functional/proxy_test.py (renamed from test/rpc-tests/proxy_test.py)0
-rwxr-xr-xtest/functional/pruning.py (renamed from test/rpc-tests/pruning.py)0
-rwxr-xr-xtest/functional/rawtransactions.py (renamed from test/rpc-tests/rawtransactions.py)0
-rwxr-xr-xtest/functional/receivedby.py (renamed from test/rpc-tests/receivedby.py)0
-rwxr-xr-xtest/functional/reindex.py (renamed from test/rpc-tests/reindex.py)0
-rwxr-xr-xtest/functional/replace-by-fee.py (renamed from test/rpc-tests/replace-by-fee.py)0
-rwxr-xr-xtest/functional/rest.py (renamed from test/rpc-tests/rest.py)0
-rwxr-xr-xtest/functional/rpcbind_test.py (renamed from test/rpc-tests/rpcbind_test.py)0
-rwxr-xr-xtest/functional/rpcnamedargs.py (renamed from test/rpc-tests/rpcnamedargs.py)0
-rwxr-xr-xtest/functional/segwit.py (renamed from test/rpc-tests/segwit.py)0
-rwxr-xr-xtest/functional/sendheaders.py (renamed from test/rpc-tests/sendheaders.py)0
-rwxr-xr-xtest/functional/signmessages.py (renamed from test/rpc-tests/signmessages.py)0
-rwxr-xr-xtest/functional/signrawtransactions.py (renamed from test/rpc-tests/signrawtransactions.py)0
-rwxr-xr-xtest/functional/smartfees.py (renamed from test/rpc-tests/smartfees.py)0
-rw-r--r--test/functional/test_framework/__init__.py (renamed from test/rpc-tests/test_framework/__init__.py)0
-rw-r--r--test/functional/test_framework/address.py (renamed from test/rpc-tests/test_framework/address.py)0
-rw-r--r--test/functional/test_framework/authproxy.py (renamed from test/rpc-tests/test_framework/authproxy.py)0
-rw-r--r--test/functional/test_framework/bignum.py (renamed from test/rpc-tests/test_framework/bignum.py)0
-rw-r--r--test/functional/test_framework/blockstore.py (renamed from test/rpc-tests/test_framework/blockstore.py)0
-rw-r--r--test/functional/test_framework/blocktools.py (renamed from test/rpc-tests/test_framework/blocktools.py)0
-rwxr-xr-xtest/functional/test_framework/comptool.py (renamed from test/rpc-tests/test_framework/comptool.py)0
-rw-r--r--test/functional/test_framework/coverage.py (renamed from test/rpc-tests/test_framework/coverage.py)0
-rw-r--r--test/functional/test_framework/key.py (renamed from test/rpc-tests/test_framework/key.py)0
-rwxr-xr-xtest/functional/test_framework/mininode.py (renamed from test/rpc-tests/test_framework/mininode.py)0
-rw-r--r--test/functional/test_framework/netutil.py (renamed from test/rpc-tests/test_framework/netutil.py)0
-rw-r--r--test/functional/test_framework/script.py (renamed from test/rpc-tests/test_framework/script.py)0
-rw-r--r--test/functional/test_framework/siphash.py (renamed from test/rpc-tests/test_framework/siphash.py)0
-rw-r--r--test/functional/test_framework/socks5.py (renamed from test/rpc-tests/test_framework/socks5.py)0
-rwxr-xr-xtest/functional/test_framework/test_framework.py (renamed from test/rpc-tests/test_framework/test_framework.py)0
-rw-r--r--test/functional/test_framework/util.py (renamed from test/rpc-tests/test_framework/util.py)0
-rwxr-xr-xtest/functional/txn_clone.py (renamed from test/rpc-tests/txn_clone.py)0
-rwxr-xr-xtest/functional/txn_doublespend.py (renamed from test/rpc-tests/txn_doublespend.py)0
-rwxr-xr-xtest/functional/wallet-accounts.py (renamed from test/rpc-tests/wallet-accounts.py)0
-rwxr-xr-xtest/functional/wallet-dump.py (renamed from test/rpc-tests/wallet-dump.py)0
-rwxr-xr-xtest/functional/wallet-hd.py (renamed from test/rpc-tests/wallet-hd.py)0
-rwxr-xr-xtest/functional/wallet.py (renamed from test/rpc-tests/wallet.py)0
-rwxr-xr-xtest/functional/walletbackup.py (renamed from test/rpc-tests/walletbackup.py)0
-rwxr-xr-xtest/functional/zapwallettxes.py (renamed from test/rpc-tests/zapwallettxes.py)0
-rwxr-xr-xtest/functional/zmq_test.py (renamed from test/rpc-tests/zmq_test.py)0
-rwxr-xr-xtest/pull-tester/rpc-tests.py16
100 files changed, 25 insertions, 26 deletions
diff --git a/.travis.yml b/.travis.yml
index ba250ec83b..b6739e1dd1 100644
--- a/.travis.yml
+++ b/.travis.yml
@@ -70,7 +70,7 @@ script:
- make $MAKEJOBS $GOAL || ( echo "Build failure. Verbose build follows." && make $GOAL V=1 ; false )
- export LD_LIBRARY_PATH=$TRAVIS_BUILD_DIR/depends/$HOST/lib
- if [ "$RUN_TESTS" = "true" ]; then make $MAKEJOBS check VERBOSE=1; fi
- - if [ "$RUN_TESTS" = "true" ]; then qa/pull-tester/rpc-tests.py --coverage; fi
+ - if [ "$RUN_TESTS" = "true" ]; then functional/pull-tester/rpc-tests.py --coverage; fi
after_script:
- echo $TRAVIS_COMMIT_RANGE
- echo $TRAVIS_COMMIT_LOG
diff --git a/Makefile.am b/Makefile.am
index a8fa1d6c3a..0316d9254f 100644
--- a/Makefile.am
+++ b/Makefile.am
@@ -61,7 +61,7 @@ OSX_PACKAGING = $(OSX_DEPLOY_SCRIPT) $(OSX_FANCY_PLIST) $(OSX_INSTALLER_ICONS) \
COVERAGE_INFO = baseline_filtered_combined.info baseline.info \
leveldb_baseline.info test_bitcoin_filtered.info total_coverage.info \
- baseline_filtered.info rpc_test.info rpc_test_filtered.info \
+ baseline_filtered.info functional_test.info functional_test_filtered.info \
leveldb_baseline_filtered.info test_bitcoin_coverage.info test_bitcoin.info
dist-hook:
@@ -194,20 +194,20 @@ test_bitcoin.info: baseline_filtered_combined.info
test_bitcoin_filtered.info: test_bitcoin.info
$(LCOV) -r $< "/usr/include/*" -o $@
-rpc_test.info: test_bitcoin_filtered.info
+functional_test.info: test_bitcoin_filtered.info
-@TIMEOUT=15 python test/pull-tester/rpc-tests.py $(EXTENDED_RPC_TESTS)
- $(LCOV) -c -d $(abs_builddir)/src --t rpc-tests -o $@
+ $(LCOV) -c -d $(abs_builddir)/src --t functional-tests -o $@
$(LCOV) -z -d $(abs_builddir)/src
$(LCOV) -z -d $(abs_builddir)/src/leveldb
-rpc_test_filtered.info: rpc_test.info
+functional_test_filtered.info: functional_test.info
$(LCOV) -r $< "/usr/include/*" -o $@
test_bitcoin_coverage.info: baseline_filtered_combined.info test_bitcoin_filtered.info
$(LCOV) -a baseline_filtered.info -a leveldb_baseline_filtered.info -a test_bitcoin_filtered.info -o $@
-total_coverage.info: baseline_filtered_combined.info test_bitcoin_filtered.info rpc_test_filtered.info
- $(LCOV) -a baseline_filtered.info -a leveldb_baseline_filtered.info -a test_bitcoin_filtered.info -a rpc_test_filtered.info -o $@ | $(GREP) "\%" | $(AWK) '{ print substr($$3,2,50) "/" $$5 }' > coverage_percent.txt
+total_coverage.info: baseline_filtered_combined.info test_bitcoin_filtered.info functional_test_filtered.info
+ $(LCOV) -a baseline_filtered.info -a leveldb_baseline_filtered.info -a test_bitcoin_filtered.info -a functional_test_filtered.info -o $@ | $(GREP) "\%" | $(AWK) '{ print substr($$3,2,50) "/" $$5 }' > coverage_percent.txt
test_bitcoin.coverage/.dirstamp: test_bitcoin_coverage.info
$(GENHTML) -s $< -o $(@D)
@@ -223,7 +223,7 @@ endif
dist_noinst_SCRIPTS = autogen.sh
-EXTRA_DIST = $(top_srcdir)/share/genbuild.sh test/pull-tester/rpc-tests.py test/rpc-tests $(DIST_CONTRIB) $(DIST_DOCS) $(WINDOWS_PACKAGING) $(OSX_PACKAGING) $(BIN_CHECKS)
+EXTRA_DIST = $(top_srcdir)/share/genbuild.sh test/pull-tester/rpc-tests.py test/functional $(DIST_CONTRIB) $(DIST_DOCS) $(WINDOWS_PACKAGING) $(OSX_PACKAGING) $(BIN_CHECKS)
CLEANFILES = $(OSX_DMG) $(BITCOIN_WIN_INSTALLER)
diff --git a/README.md b/README.md
index 4de30e0df0..ccaf8d914e 100644
--- a/README.md
+++ b/README.md
@@ -54,7 +54,7 @@ submit new unit tests for old code. Unit tests can be compiled and run
(assuming they weren't disabled in configure) with: `make check`. Further details on running
and extending unit tests can be found in [/src/test/README.md](/src/test/README.md).
-There are also [regression and integration tests](/test) of the RPC interface, written
+There are also [regression and integration tests](/test), written
in Python, that are run automatically on the build server.
These tests can be run (if the [test dependencies](/test) are installed) with: `test/pull-tester/rpc-tests.py`
diff --git a/configure.ac b/configure.ac
index b32daf0a20..3671a406d7 100644
--- a/configure.ac
+++ b/configure.ac
@@ -1147,8 +1147,7 @@ AC_SUBST(EVENT_PTHREADS_LIBS)
AC_SUBST(ZMQ_LIBS)
AC_SUBST(PROTOBUF_LIBS)
AC_SUBST(QR_LIBS)
-AC_CONFIG_FILES([Makefile src/Makefile doc/man/Makefile share/setup.nsi share/qt/Info.plist src/test/buildenv.py])
-AC_CONFIG_FILES([test/pull-tester/tests_config.ini],[chmod +x test/pull-tester/tests_config.ini])
+AC_CONFIG_FILES([Makefile src/Makefile doc/man/Makefile share/setup.nsi share/qt/Info.plist src/test/buildenv.py test/pull-tester/tests_config.ini])
AC_CONFIG_FILES([contrib/devtools/split-debug.sh],[chmod +x contrib/devtools/split-debug.sh])
AC_CONFIG_LINKS([test/pull-tester/rpc-tests.py:test/pull-tester/rpc-tests.py])
diff --git a/contrib/devtools/copyright_header.py b/contrib/devtools/copyright_header.py
index 1b70879348..6d801d3ac7 100755
--- a/contrib/devtools/copyright_header.py
+++ b/contrib/devtools/copyright_header.py
@@ -32,7 +32,7 @@ EXCLUDE = [
'src/tinyformat.h',
'src/leveldb/util/env_win.cc',
'src/crypto/ctaes/bench.c',
- 'test/rpc-tests/test_framework/bignum.py',
+ 'test/functional/test_framework/bignum.py',
# python init:
'*__init__.py',
]
diff --git a/doc/developer-notes.md b/doc/developer-notes.md
index ec608cfbde..797507cd3e 100644
--- a/doc/developer-notes.md
+++ b/doc/developer-notes.md
@@ -132,7 +132,7 @@ Run with the -testnet option to run with "play bitcoins" on the test network, if
are testing multi-machine code that needs to operate across the internet.
If you are testing something that can run on one machine, run with the -regtest option.
-In regression test mode, blocks can be created on-demand; see test/rpc-tests/ for tests
+In regression test mode, blocks can be created on-demand; see test/functional/ for tests
that run in -regtest mode.
**DEBUG_LOCKORDER**
@@ -252,7 +252,7 @@ Wallet
- *Rationale*: In RPC code that conditionally uses the wallet (such as
`validateaddress`) it is easy to forget that global pointer `pwalletMain`
- can be NULL. See `test/rpc-tests/disablewallet.py` for functional tests
+ can be NULL. See `test/functional/disablewallet.py` for functional tests
exercising the API with `-disablewallet`
- Include `db_cxx.h` (BerkeleyDB header) only when `ENABLE_WALLET` is set
diff --git a/test/README.md b/test/README.md
index d71030df56..15ebf3204e 100644
--- a/test/README.md
+++ b/test/README.md
@@ -1,5 +1,5 @@
The [pull-tester](/test/pull-tester/) folder contains a script to call
-multiple tests from the [rpc-tests](/test/rpc-tests/) folder.
+multiple tests from the [functional](/test/functional/) folder.
Every pull request to the bitcoin repository is built and run through
the regression test suite. You can also run all or only individual
@@ -83,5 +83,5 @@ killall bitcoind
Writing tests
=============
You are encouraged to write tests for new or existing features.
-Further information about the test framework and individual RPC
-tests is found in [test/rpc-tests](/test/rpc-tests).
+Further information about the test framework and individual functional
+tests is found in [test/functional](/test/functional).
diff --git a/test/rpc-tests/.gitignore b/test/functional/.gitignore
index cb41d94423..cb41d94423 100644
--- a/test/rpc-tests/.gitignore
+++ b/test/functional/.gitignore
diff --git a/test/rpc-tests/README.md b/test/functional/README.md
index 651b01f18a..651b01f18a 100644
--- a/test/rpc-tests/README.md
+++ b/test/functional/README.md
diff --git a/test/rpc-tests/abandonconflict.py b/test/functional/abandonconflict.py
index 887dbebd4f..887dbebd4f 100755
--- a/test/rpc-tests/abandonconflict.py
+++ b/test/functional/abandonconflict.py
diff --git a/test/rpc-tests/assumevalid.py b/test/functional/assumevalid.py
index c60c8e6d1a..c60c8e6d1a 100755
--- a/test/rpc-tests/assumevalid.py
+++ b/test/functional/assumevalid.py
diff --git a/test/rpc-tests/bip65-cltv-p2p.py b/test/functional/bip65-cltv-p2p.py
index 63d05e8fc9..63d05e8fc9 100755
--- a/test/rpc-tests/bip65-cltv-p2p.py
+++ b/test/functional/bip65-cltv-p2p.py
diff --git a/test/rpc-tests/bip65-cltv.py b/test/functional/bip65-cltv.py
index 7f13bb9952..7f13bb9952 100755
--- a/test/rpc-tests/bip65-cltv.py
+++ b/test/functional/bip65-cltv.py
diff --git a/test/rpc-tests/bip68-112-113-p2p.py b/test/functional/bip68-112-113-p2p.py
index 0867f42585..0867f42585 100755
--- a/test/rpc-tests/bip68-112-113-p2p.py
+++ b/test/functional/bip68-112-113-p2p.py
diff --git a/test/rpc-tests/bip68-sequence.py b/test/functional/bip68-sequence.py
index 3ed6ebe044..3ed6ebe044 100755
--- a/test/rpc-tests/bip68-sequence.py
+++ b/test/functional/bip68-sequence.py
diff --git a/test/rpc-tests/bip9-softforks.py b/test/functional/bip9-softforks.py
index 0dffd06e1a..0dffd06e1a 100755
--- a/test/rpc-tests/bip9-softforks.py
+++ b/test/functional/bip9-softforks.py
diff --git a/test/rpc-tests/bipdersig-p2p.py b/test/functional/bipdersig-p2p.py
index 22bd39fbe5..22bd39fbe5 100755
--- a/test/rpc-tests/bipdersig-p2p.py
+++ b/test/functional/bipdersig-p2p.py
diff --git a/test/rpc-tests/bipdersig.py b/test/functional/bipdersig.py
index 371cc41bb7..371cc41bb7 100755
--- a/test/rpc-tests/bipdersig.py
+++ b/test/functional/bipdersig.py
diff --git a/test/rpc-tests/blockchain.py b/test/functional/blockchain.py
index 596aed50ec..596aed50ec 100755
--- a/test/rpc-tests/blockchain.py
+++ b/test/functional/blockchain.py
diff --git a/test/rpc-tests/bumpfee.py b/test/functional/bumpfee.py
index 8f75e9ed4d..8f75e9ed4d 100755
--- a/test/rpc-tests/bumpfee.py
+++ b/test/functional/bumpfee.py
diff --git a/test/rpc-tests/create_cache.py b/test/functional/create_cache.py
index 13eac92bbc..e4b6dbc2d1 100755
--- a/test/rpc-tests/create_cache.py
+++ b/test/functional/create_cache.py
@@ -5,7 +5,7 @@
"""Create a blockchain cache.
Creating a cache of the blockchain speeds up test execution when running
-multiple qa tests. This helper script is executed by rpc-tests when multiple
+multiple functional tests. This helper script is executed by rpc-tests when multiple
tests are being run in parallel.
"""
diff --git a/test/rpc-tests/decodescript.py b/test/functional/decodescript.py
index 5555e96c44..5555e96c44 100755
--- a/test/rpc-tests/decodescript.py
+++ b/test/functional/decodescript.py
diff --git a/test/rpc-tests/disablewallet.py b/test/functional/disablewallet.py
index 2f729e19bf..2f729e19bf 100755
--- a/test/rpc-tests/disablewallet.py
+++ b/test/functional/disablewallet.py
diff --git a/test/rpc-tests/forknotify.py b/test/functional/forknotify.py
index c2724ba5df..c2724ba5df 100755
--- a/test/rpc-tests/forknotify.py
+++ b/test/functional/forknotify.py
diff --git a/test/rpc-tests/fundrawtransaction.py b/test/functional/fundrawtransaction.py
index fd330ef277..fd330ef277 100755
--- a/test/rpc-tests/fundrawtransaction.py
+++ b/test/functional/fundrawtransaction.py
diff --git a/test/rpc-tests/getblocktemplate_longpoll.py b/test/functional/getblocktemplate_longpoll.py
index bbe1dda5f7..bbe1dda5f7 100755
--- a/test/rpc-tests/getblocktemplate_longpoll.py
+++ b/test/functional/getblocktemplate_longpoll.py
diff --git a/test/rpc-tests/getblocktemplate_proposals.py b/test/functional/getblocktemplate_proposals.py
index 67745f77d1..67745f77d1 100755
--- a/test/rpc-tests/getblocktemplate_proposals.py
+++ b/test/functional/getblocktemplate_proposals.py
diff --git a/test/rpc-tests/getchaintips.py b/test/functional/getchaintips.py
index 14222334a6..14222334a6 100755
--- a/test/rpc-tests/getchaintips.py
+++ b/test/functional/getchaintips.py
diff --git a/test/rpc-tests/httpbasics.py b/test/functional/httpbasics.py
index 8f35f0ab87..8f35f0ab87 100755
--- a/test/rpc-tests/httpbasics.py
+++ b/test/functional/httpbasics.py
diff --git a/test/rpc-tests/import-rescan.py b/test/functional/import-rescan.py
index 0218a46168..0218a46168 100755
--- a/test/rpc-tests/import-rescan.py
+++ b/test/functional/import-rescan.py
diff --git a/test/rpc-tests/importmulti.py b/test/functional/importmulti.py
index aa03c6780a..aa03c6780a 100755
--- a/test/rpc-tests/importmulti.py
+++ b/test/functional/importmulti.py
diff --git a/test/rpc-tests/importprunedfunds.py b/test/functional/importprunedfunds.py
index b4c8ee6c70..b4c8ee6c70 100755
--- a/test/rpc-tests/importprunedfunds.py
+++ b/test/functional/importprunedfunds.py
diff --git a/test/rpc-tests/invalidateblock.py b/test/functional/invalidateblock.py
index 8c80b64003..8c80b64003 100755
--- a/test/rpc-tests/invalidateblock.py
+++ b/test/functional/invalidateblock.py
diff --git a/test/rpc-tests/invalidblockrequest.py b/test/functional/invalidblockrequest.py
index eabc0db8df..eabc0db8df 100755
--- a/test/rpc-tests/invalidblockrequest.py
+++ b/test/functional/invalidblockrequest.py
diff --git a/test/rpc-tests/invalidtxrequest.py b/test/functional/invalidtxrequest.py
index a9ac231f09..a9ac231f09 100755
--- a/test/rpc-tests/invalidtxrequest.py
+++ b/test/functional/invalidtxrequest.py
diff --git a/test/rpc-tests/keypool.py b/test/functional/keypool.py
index cee58563f0..cee58563f0 100755
--- a/test/rpc-tests/keypool.py
+++ b/test/functional/keypool.py
diff --git a/test/rpc-tests/listsinceblock.py b/test/functional/listsinceblock.py
index a75e66c8c4..a75e66c8c4 100755
--- a/test/rpc-tests/listsinceblock.py
+++ b/test/functional/listsinceblock.py
diff --git a/test/rpc-tests/listtransactions.py b/test/functional/listtransactions.py
index 68d14093ce..68d14093ce 100755
--- a/test/rpc-tests/listtransactions.py
+++ b/test/functional/listtransactions.py
diff --git a/test/rpc-tests/maxblocksinflight.py b/test/functional/maxblocksinflight.py
index 2c3766125a..2c3766125a 100755
--- a/test/rpc-tests/maxblocksinflight.py
+++ b/test/functional/maxblocksinflight.py
diff --git a/test/rpc-tests/maxuploadtarget.py b/test/functional/maxuploadtarget.py
index 40cd85c9ec..40cd85c9ec 100755
--- a/test/rpc-tests/maxuploadtarget.py
+++ b/test/functional/maxuploadtarget.py
diff --git a/test/rpc-tests/mempool_limit.py b/test/functional/mempool_limit.py
index a7ca576aee..a7ca576aee 100755
--- a/test/rpc-tests/mempool_limit.py
+++ b/test/functional/mempool_limit.py
diff --git a/test/rpc-tests/mempool_packages.py b/test/functional/mempool_packages.py
index 17e3a9a967..17e3a9a967 100755
--- a/test/rpc-tests/mempool_packages.py
+++ b/test/functional/mempool_packages.py
diff --git a/test/rpc-tests/mempool_reorg.py b/test/functional/mempool_reorg.py
index 812b54ffcb..812b54ffcb 100755
--- a/test/rpc-tests/mempool_reorg.py
+++ b/test/functional/mempool_reorg.py
diff --git a/test/rpc-tests/mempool_resurrect_test.py b/test/functional/mempool_resurrect_test.py
index 727892d1f2..727892d1f2 100755
--- a/test/rpc-tests/mempool_resurrect_test.py
+++ b/test/functional/mempool_resurrect_test.py
diff --git a/test/rpc-tests/mempool_spendcoinbase.py b/test/functional/mempool_spendcoinbase.py
index f562a93d86..f562a93d86 100755
--- a/test/rpc-tests/mempool_spendcoinbase.py
+++ b/test/functional/mempool_spendcoinbase.py
diff --git a/test/rpc-tests/merkle_blocks.py b/test/functional/merkle_blocks.py
index 5963f2e7b6..5963f2e7b6 100755
--- a/test/rpc-tests/merkle_blocks.py
+++ b/test/functional/merkle_blocks.py
diff --git a/test/rpc-tests/multi_rpc.py b/test/functional/multi_rpc.py
index 3b74bf1c46..3b74bf1c46 100755
--- a/test/rpc-tests/multi_rpc.py
+++ b/test/functional/multi_rpc.py
diff --git a/test/rpc-tests/nodehandling.py b/test/functional/nodehandling.py
index a6b10a0d83..a6b10a0d83 100755
--- a/test/rpc-tests/nodehandling.py
+++ b/test/functional/nodehandling.py
diff --git a/test/rpc-tests/nulldummy.py b/test/functional/nulldummy.py
index 369c593a90..369c593a90 100755
--- a/test/rpc-tests/nulldummy.py
+++ b/test/functional/nulldummy.py
diff --git a/test/rpc-tests/p2p-acceptblock.py b/test/functional/p2p-acceptblock.py
index e1111da4ae..e1111da4ae 100755
--- a/test/rpc-tests/p2p-acceptblock.py
+++ b/test/functional/p2p-acceptblock.py
diff --git a/test/rpc-tests/p2p-compactblocks.py b/test/functional/p2p-compactblocks.py
index 1fc0312c34..1fc0312c34 100755
--- a/test/rpc-tests/p2p-compactblocks.py
+++ b/test/functional/p2p-compactblocks.py
diff --git a/test/rpc-tests/p2p-feefilter.py b/test/functional/p2p-feefilter.py
index d8f07700d0..d8f07700d0 100755
--- a/test/rpc-tests/p2p-feefilter.py
+++ b/test/functional/p2p-feefilter.py
diff --git a/test/rpc-tests/p2p-fullblocktest.py b/test/functional/p2p-fullblocktest.py
index 274dbb8a92..274dbb8a92 100755
--- a/test/rpc-tests/p2p-fullblocktest.py
+++ b/test/functional/p2p-fullblocktest.py
diff --git a/test/rpc-tests/p2p-leaktests.py b/test/functional/p2p-leaktests.py
index 3a843197fb..3a843197fb 100755
--- a/test/rpc-tests/p2p-leaktests.py
+++ b/test/functional/p2p-leaktests.py
diff --git a/test/rpc-tests/p2p-mempool.py b/test/functional/p2p-mempool.py
index 0aa9c90e8f..0aa9c90e8f 100755
--- a/test/rpc-tests/p2p-mempool.py
+++ b/test/functional/p2p-mempool.py
diff --git a/test/rpc-tests/p2p-segwit.py b/test/functional/p2p-segwit.py
index dcf2b9a7de..dcf2b9a7de 100755
--- a/test/rpc-tests/p2p-segwit.py
+++ b/test/functional/p2p-segwit.py
diff --git a/test/rpc-tests/p2p-timeouts.py b/test/functional/p2p-timeouts.py
index 498acb23fe..498acb23fe 100755
--- a/test/rpc-tests/p2p-timeouts.py
+++ b/test/functional/p2p-timeouts.py
diff --git a/test/rpc-tests/p2p-versionbits-warning.py b/test/functional/p2p-versionbits-warning.py
index dc714e9a4a..dc714e9a4a 100755
--- a/test/rpc-tests/p2p-versionbits-warning.py
+++ b/test/functional/p2p-versionbits-warning.py
diff --git a/test/rpc-tests/preciousblock.py b/test/functional/preciousblock.py
index 30b0b5a301..30b0b5a301 100755
--- a/test/rpc-tests/preciousblock.py
+++ b/test/functional/preciousblock.py
diff --git a/test/rpc-tests/prioritise_transaction.py b/test/functional/prioritise_transaction.py
index 0b04ad17ab..0b04ad17ab 100755
--- a/test/rpc-tests/prioritise_transaction.py
+++ b/test/functional/prioritise_transaction.py
diff --git a/test/rpc-tests/proxy_test.py b/test/functional/proxy_test.py
index 748e3e69f6..748e3e69f6 100755
--- a/test/rpc-tests/proxy_test.py
+++ b/test/functional/proxy_test.py
diff --git a/test/rpc-tests/pruning.py b/test/functional/pruning.py
index cc84c8c085..cc84c8c085 100755
--- a/test/rpc-tests/pruning.py
+++ b/test/functional/pruning.py
diff --git a/test/rpc-tests/rawtransactions.py b/test/functional/rawtransactions.py
index 0374d8984a..0374d8984a 100755
--- a/test/rpc-tests/rawtransactions.py
+++ b/test/functional/rawtransactions.py
diff --git a/test/rpc-tests/receivedby.py b/test/functional/receivedby.py
index 248bcdbd68..248bcdbd68 100755
--- a/test/rpc-tests/receivedby.py
+++ b/test/functional/receivedby.py
diff --git a/test/rpc-tests/reindex.py b/test/functional/reindex.py
index 0cebb0466f..0cebb0466f 100755
--- a/test/rpc-tests/reindex.py
+++ b/test/functional/reindex.py
diff --git a/test/rpc-tests/replace-by-fee.py b/test/functional/replace-by-fee.py
index 163c304eba..163c304eba 100755
--- a/test/rpc-tests/replace-by-fee.py
+++ b/test/functional/replace-by-fee.py
diff --git a/test/rpc-tests/rest.py b/test/functional/rest.py
index 776211d301..776211d301 100755
--- a/test/rpc-tests/rest.py
+++ b/test/functional/rest.py
diff --git a/test/rpc-tests/rpcbind_test.py b/test/functional/rpcbind_test.py
index 8720a345ce..8720a345ce 100755
--- a/test/rpc-tests/rpcbind_test.py
+++ b/test/functional/rpcbind_test.py
diff --git a/test/rpc-tests/rpcnamedargs.py b/test/functional/rpcnamedargs.py
index f6175c8ca7..f6175c8ca7 100755
--- a/test/rpc-tests/rpcnamedargs.py
+++ b/test/functional/rpcnamedargs.py
diff --git a/test/rpc-tests/segwit.py b/test/functional/segwit.py
index 5b1fba8eec..5b1fba8eec 100755
--- a/test/rpc-tests/segwit.py
+++ b/test/functional/segwit.py
diff --git a/test/rpc-tests/sendheaders.py b/test/functional/sendheaders.py
index de7f5e0849..de7f5e0849 100755
--- a/test/rpc-tests/sendheaders.py
+++ b/test/functional/sendheaders.py
diff --git a/test/rpc-tests/signmessages.py b/test/functional/signmessages.py
index 91f5abef5d..91f5abef5d 100755
--- a/test/rpc-tests/signmessages.py
+++ b/test/functional/signmessages.py
diff --git a/test/rpc-tests/signrawtransactions.py b/test/functional/signrawtransactions.py
index b24162ab97..b24162ab97 100755
--- a/test/rpc-tests/signrawtransactions.py
+++ b/test/functional/signrawtransactions.py
diff --git a/test/rpc-tests/smartfees.py b/test/functional/smartfees.py
index 49f2df5c37..49f2df5c37 100755
--- a/test/rpc-tests/smartfees.py
+++ b/test/functional/smartfees.py
diff --git a/test/rpc-tests/test_framework/__init__.py b/test/functional/test_framework/__init__.py
index e69de29bb2..e69de29bb2 100644
--- a/test/rpc-tests/test_framework/__init__.py
+++ b/test/functional/test_framework/__init__.py
diff --git a/test/rpc-tests/test_framework/address.py b/test/functional/test_framework/address.py
index 96bebe1ea1..96bebe1ea1 100644
--- a/test/rpc-tests/test_framework/address.py
+++ b/test/functional/test_framework/address.py
diff --git a/test/rpc-tests/test_framework/authproxy.py b/test/functional/test_framework/authproxy.py
index 9ab3094b06..9ab3094b06 100644
--- a/test/rpc-tests/test_framework/authproxy.py
+++ b/test/functional/test_framework/authproxy.py
diff --git a/test/rpc-tests/test_framework/bignum.py b/test/functional/test_framework/bignum.py
index 024611da6e..024611da6e 100644
--- a/test/rpc-tests/test_framework/bignum.py
+++ b/test/functional/test_framework/bignum.py
diff --git a/test/rpc-tests/test_framework/blockstore.py b/test/functional/test_framework/blockstore.py
index 4cfd682bb5..4cfd682bb5 100644
--- a/test/rpc-tests/test_framework/blockstore.py
+++ b/test/functional/test_framework/blockstore.py
diff --git a/test/rpc-tests/test_framework/blocktools.py b/test/functional/test_framework/blocktools.py
index 2c9a0857df..2c9a0857df 100644
--- a/test/rpc-tests/test_framework/blocktools.py
+++ b/test/functional/test_framework/blocktools.py
diff --git a/test/rpc-tests/test_framework/comptool.py b/test/functional/test_framework/comptool.py
index 70d1d700ef..70d1d700ef 100755
--- a/test/rpc-tests/test_framework/comptool.py
+++ b/test/functional/test_framework/comptool.py
diff --git a/test/rpc-tests/test_framework/coverage.py b/test/functional/test_framework/coverage.py
index 3f87ef91f6..3f87ef91f6 100644
--- a/test/rpc-tests/test_framework/coverage.py
+++ b/test/functional/test_framework/coverage.py
diff --git a/test/rpc-tests/test_framework/key.py b/test/functional/test_framework/key.py
index 85a6158a2f..85a6158a2f 100644
--- a/test/rpc-tests/test_framework/key.py
+++ b/test/functional/test_framework/key.py
diff --git a/test/rpc-tests/test_framework/mininode.py b/test/functional/test_framework/mininode.py
index aace17a043..aace17a043 100755
--- a/test/rpc-tests/test_framework/mininode.py
+++ b/test/functional/test_framework/mininode.py
diff --git a/test/rpc-tests/test_framework/netutil.py b/test/functional/test_framework/netutil.py
index 45d8e22d22..45d8e22d22 100644
--- a/test/rpc-tests/test_framework/netutil.py
+++ b/test/functional/test_framework/netutil.py
diff --git a/test/rpc-tests/test_framework/script.py b/test/functional/test_framework/script.py
index 3d9572788e..3d9572788e 100644
--- a/test/rpc-tests/test_framework/script.py
+++ b/test/functional/test_framework/script.py
diff --git a/test/rpc-tests/test_framework/siphash.py b/test/functional/test_framework/siphash.py
index f68ecad36b..f68ecad36b 100644
--- a/test/rpc-tests/test_framework/siphash.py
+++ b/test/functional/test_framework/siphash.py
diff --git a/test/rpc-tests/test_framework/socks5.py b/test/functional/test_framework/socks5.py
index dd7624d454..dd7624d454 100644
--- a/test/rpc-tests/test_framework/socks5.py
+++ b/test/functional/test_framework/socks5.py
diff --git a/test/rpc-tests/test_framework/test_framework.py b/test/functional/test_framework/test_framework.py
index d7072fa78d..d7072fa78d 100755
--- a/test/rpc-tests/test_framework/test_framework.py
+++ b/test/functional/test_framework/test_framework.py
diff --git a/test/rpc-tests/test_framework/util.py b/test/functional/test_framework/util.py
index 23ac324510..23ac324510 100644
--- a/test/rpc-tests/test_framework/util.py
+++ b/test/functional/test_framework/util.py
diff --git a/test/rpc-tests/txn_clone.py b/test/functional/txn_clone.py
index 7a3b8d3474..7a3b8d3474 100755
--- a/test/rpc-tests/txn_clone.py
+++ b/test/functional/txn_clone.py
diff --git a/test/rpc-tests/txn_doublespend.py b/test/functional/txn_doublespend.py
index 5b12cf4c29..5b12cf4c29 100755
--- a/test/rpc-tests/txn_doublespend.py
+++ b/test/functional/txn_doublespend.py
diff --git a/test/rpc-tests/wallet-accounts.py b/test/functional/wallet-accounts.py
index ea12d4ec22..ea12d4ec22 100755
--- a/test/rpc-tests/wallet-accounts.py
+++ b/test/functional/wallet-accounts.py
diff --git a/test/rpc-tests/wallet-dump.py b/test/functional/wallet-dump.py
index b819b72b75..b819b72b75 100755
--- a/test/rpc-tests/wallet-dump.py
+++ b/test/functional/wallet-dump.py
diff --git a/test/rpc-tests/wallet-hd.py b/test/functional/wallet-hd.py
index c40662dc3d..c40662dc3d 100755
--- a/test/rpc-tests/wallet-hd.py
+++ b/test/functional/wallet-hd.py
diff --git a/test/rpc-tests/wallet.py b/test/functional/wallet.py
index 80f74fa108..80f74fa108 100755
--- a/test/rpc-tests/wallet.py
+++ b/test/functional/wallet.py
diff --git a/test/rpc-tests/walletbackup.py b/test/functional/walletbackup.py
index af1718572f..af1718572f 100755
--- a/test/rpc-tests/walletbackup.py
+++ b/test/functional/walletbackup.py
diff --git a/test/rpc-tests/zapwallettxes.py b/test/functional/zapwallettxes.py
index ce446e44a3..ce446e44a3 100755
--- a/test/rpc-tests/zapwallettxes.py
+++ b/test/functional/zapwallettxes.py
diff --git a/test/rpc-tests/zmq_test.py b/test/functional/zmq_test.py
index e6f18b0b93..e6f18b0b93 100755
--- a/test/rpc-tests/zmq_test.py
+++ b/test/functional/zmq_test.py
diff --git a/test/pull-tester/rpc-tests.py b/test/pull-tester/rpc-tests.py
index 925e19f09a..78a754a28d 100755
--- a/test/pull-tester/rpc-tests.py
+++ b/test/pull-tester/rpc-tests.py
@@ -8,7 +8,7 @@ rpc-tests.py - run regression test suite
This module calls down into individual test cases via subprocess. It will
forward all unrecognized arguments onto the individual test scripts.
-RPC tests are disabled on Windows by default. Use --force to run them anyway.
+Functional tests are disabled on Windows by default. Use --force to run them anyway.
For a description of arguments recognized by test scripts, see
`test/pull-tester/test_framework/test_framework.py:BitcoinTestFramework.main`.
@@ -161,7 +161,7 @@ def main():
sys.exit(0)
if not (enable_wallet and enable_utils and enable_bitcoind):
- print("No rpc tests to run. Wallet, utils, and bitcoind must all be enabled")
+ print("No functional tests to run. Wallet, utils, and bitcoind must all be enabled")
print("Rerun `configure` with -enable-wallet, -with-utils and -with-daemon and rerun make")
sys.exit(0)
@@ -206,7 +206,7 @@ def main():
if args.help:
# Print help for rpc-tests.py, then print help of the first script and exit.
parser.print_help()
- subprocess.check_call((config["environment"]["SRCDIR"] + '/test/rpc-tests/' + test_list[0]).split() + ['-h'])
+ subprocess.check_call((config["environment"]["SRCDIR"] + '/test/functional/' + test_list[0]).split() + ['-h'])
sys.exit(0)
run_tests(test_list, config["environment"]["SRCDIR"], config["environment"]["BUILDDIR"], config["environment"]["EXEEXT"], args.jobs, args.coverage, passon_args)
@@ -222,7 +222,7 @@ def run_tests(test_list, src_dir, build_dir, exeext, jobs=1, enable_coverage=Fal
if "BITCOIND" not in os.environ:
os.environ["BITCOIND"] = build_dir + '/src/bitcoind' + exeext
- tests_dir = src_dir + '/test/rpc-tests/'
+ tests_dir = src_dir + '/test/functional/'
flags = ["--srcdir={}/src".format(build_dir)] + args
flags.append("--cachedir=%s/test/cache" % build_dir)
@@ -243,7 +243,7 @@ def run_tests(test_list, src_dir, build_dir, exeext, jobs=1, enable_coverage=Fal
time_sum = 0
time0 = time.time()
- job_queue = RPCTestHandler(jobs, tests_dir, test_list, flags)
+ job_queue = TestHandler(jobs, tests_dir, test_list, flags)
max_len_name = len(max(test_list, key=len))
results = BOLD[1] + "%s | %s | %s\n\n" % ("TEST".ljust(max_len_name), "PASSED", "DURATION") + BOLD[0]
@@ -271,7 +271,7 @@ def run_tests(test_list, src_dir, build_dir, exeext, jobs=1, enable_coverage=Fal
sys.exit(not all_passed)
-class RPCTestHandler:
+class TestHandler:
"""
Trigger the testscrips passed in via the list.
"""
@@ -335,7 +335,7 @@ class RPCCoverage(object):
After all tests complete, the commands run are combined and diff'd against
the complete list to calculate uncovered RPC commands.
- See also: test/rpc-tests/test_framework/coverage.py
+ See also: test/functional/test_framework/coverage.py
"""
def __init__(self):
@@ -363,7 +363,7 @@ class RPCCoverage(object):
Return a set of currently untested RPC commands.
"""
# This is shared from `test/rpc-tests/test-framework/coverage.py`
reference_filename = 'rpc_interface.txt'
coverage_file_prefix = 'coverage.'
@@ -363,7 +363,7 @@ class RPCCoverage(object):
Return a set of currently untested RPC commands.
"""
- # This is shared from `test/rpc-tests/test-framework/coverage.py`
+ # This is shared from `test/functional/test-framework/coverage.py`
reference_filename = 'rpc_interface.txt'
coverage_file_prefix = 'coverage.'